@@ -103,7 +103,7 @@ private:
     return R_COLOR(R_RED(col), R_GREEN(col), R_BLUE(col), R_ALPHA(col)).premultiply();
   }
   inline bool visibleColour(unsigned int col) {
-    return (int) col != NA_INTEGER && R_ALPHA(col) != 0;
+    return (int) R_ALPHA(col) != 0;
   }
   inline agg::line_cap_e convertLineend(R_GE_lineend lend) {
     switch (lend) {
